# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""change curator-wf metadata.json data_location to data_src

The data_location key is used by the workflow engine for other stuff, want an isolated key for curator's data source.

Revision ID: 1c435b5d7a8d
Revises: 49b7c8150e72
Create Date: 2024-01-02 08:57:57.131486

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "1c435b5d7a8d"
down_revision = "49b7c8150e72"
branch_labels = None
depends_on = None

old_json = """{
  "product_locator": "{{product_locator}}",{{#data_location}}
  "data_location": "{{data_location}}",{{/data_location}}
  "product_type": "{{product_type}}",{{#target_list}}
  "target_list": ["{{target_list}}"],{{/target_list}}{{#product_group_id}}
  "product_group_id": {{product_group_id}},{{/product_group_id}}{{#input_group_locator}}
  "input_group_locator": "{{input_group_locator}}",{{/input_group_locator}}
  "projectMetadata": {
    "telescope": "{{telescope}}",
    "projectCode": "{{projectCode}}"
  }
}
"""

new_json = """{
  "product_locator": "{{product_locator}}",{{#data_src}}
  "data_location": "{{data_src}}",{{/data_src}}
  "product_type": "{{product_type}}",{{#target_list}}
  "target_list": ["{{target_list}}"],{{/target_list}}{{#product_group_id}}
  "product_group_id": {{product_group_id}},{{/product_group_id}}{{#input_group_locator}}
  "input_group_locator": "{{input_group_locator}}",{{/input_group_locator}}
  "projectMetadata": {
    "telescope": "{{telescope}}",
    "projectCode": "{{projectCode}}"
  }
}
"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{new_json}' WHERE filename='metadata.json' AND workflow_name='curator'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_json}' WHERE filename='metadata.json' AND workflow_name='curator'
        """
    )
